#
# spec file for package assimp
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover 5
Name:           assimp
Version:        5.1.3
Release:        bp154.1.38
Summary:        Library to load and process 3D scenes from various data formats
License:        BSD-3-Clause AND MIT
Group:          Development/Libraries/C and C++
URL:            https://assimp.org/
Source0:        %{name}-%{version}.tar.xz
BuildRequires:  cmake
BuildRequires:  dos2unix
BuildRequires:  gcc-c++
BuildRequires:  irrlicht-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(minizip)
BuildRequires:  pkgconfig(zlib)

%description
Assimp is a library to load and process geometric scenes from various data formats.
It is tailored at typical game scenarios by supporting a node hierarchy, static or skinned meshes,
materials, bone animations and potential texture data. The library is not designed for speed,
it is primarily useful for importing assets from various sources once and storing it in a
engine-specific format for easy and fast every-day-loading.

%package -n libassimp%{sover}
Summary:        Library to load and process 3D scenes from various data formats
Group:          System/Libraries

%description -n libassimp%{sover}
Assimp is a library to load and process geometric scenes from various data formats.
It is tailored at typical game scenarios by supporting a node hierarchy, static or skinned meshes,
materials, bone animations and potential texture data. The library is not designed for speed,
it is primarily useful for importing assets from various sources once and storing it in a
engine-specific format for easy and fast every-day-loading.

%package devel
Summary:        Headers, docs and command-line utility for assimp
Group:          Development/Libraries/C and C++
Requires:       glibc-devel
Requires:       libassimp%{sover} = %{version}
Requires:       libstdc++-devel
Requires:       pkgconfig(minizip)

%description devel
Assimp is a library to load and process geometric scenes from various data formats.
It is tailored at typical game scenarios by supporting a node hierarchy, static or skinned meshes,
materials, bone animations and potential texture data. The library is not designed for speed,
it is primarily useful for importing assets from various sources once and storing it in a
engine-specific format for easy and fast every-day-loading.

%prep
%autosetup -p1

%build
%cmake

%cmake_build

%install
%cmake_install
find %{buildroot} -type f -name "*.la" -delete -print

%check
pushd build/test
LD_LIBRARY_PATH=%{buildroot}%{_libdir} ctest --output-on-failure --force-new-ctest-process
popd

%post -n lib%{name}%{sover}  -p /sbin/ldconfig
%postun -n lib%{name}%{sover} -p /sbin/ldconfig

%files -n lib%{name}%{sover}
%license LICENSE
%{_libdir}/libassimp.so.%{sover}*

%files devel
%doc README CHANGES CREDITS
%{_includedir}/assimp/
%{_bindir}/assimp
%{_libdir}/libassimp.so
%{_libdir}/cmake/*
%{_libdir}/pkgconfig/assimp.pc

%changelog
* Sun Dec  5 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.1.3
  * Update blender importer to work with Blender 2.8+ files
  * Added checks for out of bounds data access/writing
  * Interpolate euler rotations for quaternion animations
  * Fix file-extension check for X3D-files
  * Update CMakeLists.txt
* Thu Dec  2 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.1.2. Changes since 5.1.0:
  * Fixed an incorrect indeiciesType in the glTF2 sparse accessor.
  * Prevent out-of-range memory writes by sparse accessors
  * Delete test/models/3DS/UVTransformTest directory
  * Do not build ziplib when 3MF exporter is disabled.
  * Collada: Read value, not attribute
  * Redefine deprecated glTF-specific PBR material macros
- Fix assimp-devel dependencies. minizip is required.
* Sat Nov 13 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.1.0
  * Check https://github.com/assimp/assimp/releases/tag/v5.1.0
    for the full list of changes
- Drop do-not-install-irrXML.patch. No longer needed.
- Drop obsolete patches:
  * 0001-Fix-build-with-GCC-11.patch
  * 0001-use-GNUInstallDirs-where-possible.patch
* Mon Feb  8 2021 Christophe Giboudeaux <christophe@krop.fr>
- Add patch to fix build with GCC11:
  * 0001-Fix-build-with-GCC-11.patch (boo#1181859)
* Mon Sep 21 2020 Christophe Giboudeaux <christophe@krop.fr>
- Add a _constraints file for ppc64/ppc64le builds.
* Thu Sep 17 2020 Christophe Giboudeaux <christophe@krop.fr>
- Remove unneeded build dependencies.
  assimp doesn't need Qt5, boost, devIL and glu.
* Thu Jul  9 2020 Christophe Giboudeaux <christophe@krop.fr>
- Restore the _service file.
  Assimp still ships files which are not allowed in openSUSE.
* Wed Jun 10 2020 Christophe Giboudeaux <christophe@krop.fr>
- Add upstream patch to fix the broken CMake config files:
  * 0001-use-GNUInstallDirs-where-possible.patch
  (adapted for the 5.0.1 release)
* Wed May 20 2020 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 5.0.1
  * Added texture types: BASE_COLOR, NORMAL_CAMERA, EMISSION_COLOR,
    METALNESS, DIFFUSE_ROUGHNESS
  * Fixed various issues and memory leaks
  * 3DS: Explicitly pass "UNNAMED" as 3DS root node name and fix
    more thread-safety issue in 3DS loader.
  * 3MF: Introduce first prototype for basematerial support
  * AssJSon: Add json export.
  * Various other file support improvements
- Dropped viewer subpackage, as it now requires DirectX
- Removed not needed disable-gitrevision-test.patch
- Rebased do-not-install-irrXML.patch
- Removed not needed install-viewer.patch
- Removed _service
* Wed Jan 23 2019 Jan Engelhardt <jengelh@inai.de>
- sanitize_source.sh was removed in the 4.1.0 update; restore its
  logic with a new _service file and recreate the tarball.
* Thu Jan 17 2019 Jan Engelhardt <jengelh@inai.de>
- Fix incorrect summary for libassimp*.
* Sat Aug 11 2018 rpm@fthiessen.de
- Update to 4.1.0
  * Added support for Export 3MF (experimental)
  * Added supprt for Import / Export glTF 2
  * Prevent failing stringstream to crash the export process
  * Fix invalid access to mesh array when the array is
    empty in Blender, also fixed short overflow.
  * Fixed memory leak in AMFImporter
  * Fixed IOStream leak in UnrealLoader:
  * Fixed out-of-bounds read in MaterialSystem unit test
  * Added support for SIB models from Silo 2.5
- Changes from 4.0.1
  * StreamReader: fix out-of-range exception
- Changes From 4.0.0
  * New QT-Widget based assimp-viewer
  * Open3DGC codec supported by glFT-importer
  * glTF: Read and write transparency values
  * Support for X3D, AMF and Lugdunum3D
  * MDLLoader: fix resource leak.
  * Fix memory leak in Collada importer
  * Fixed many FBX bugs
- Added %%check section, run unit tests
- Added disable-gitrevision-test.patch to fix testsuite as we do
  not build from git, git rev will test will fail.
- Added do-not-install-irrXML.patch to prevent cmake from
  installing the irrXML (static) library.
- install-viewer.patch: Install viewer component
* Thu Apr 20 2017 jengelh@inai.de
- Rename %%soname to %%sover to better reflects its use.
- Repackage original tarball with the test/models-nonbsd/
  directory removed.
* Mon Sep  5 2016 rpm@fthiessen.de
- Update to new upstream release 3.3.1
  * Fix BlenderTesselator: offsetof operator
  * C++11 support
  * OpenGEX: add support for cameras and lights
  * Enable export by pyAssimp
  * Add functionality to perform a singlepost-processing step
  * Fix of many resource leaks in unittests and main lib
* Thu Jun 16 2016 jengelh@inai.de
- Update to new upstream release 3.2
  * Support for FBX 2013 and newer, binary and ASCII
  * Support for OGRE binary mesh and skeleton format
  * Updated BLEND support for newer Blender versions
  * Support for arbitrary meta data, used to hold FBX and DAE metadata
  * OBJ Export now produces smaller files
  * Meshes can now have names, this is supported by the major importers
  * Improved IFC geometry generation
  * M3 support has been removed
  * Experimental OpenGEX support
* Tue Sep  3 2013 joop.boonen@opensuse.org
- Fixed the build problem with docdir
  moved samples/ to doc
* Fri Feb  1 2013 joop.boonen@opensuse.org
- Improved the spec file, changed the names and cleaned the spec file
* Sun Jul 29 2012 sergey.shambir.auto@gmail.c
- some improvements form *.spec at home:hcostelha repository
* Sat Jul 28 2012 sergey.shambir.auto@gmail.c
- initial package of version 3.0
